@@ -11,6 +11,7 @@ register_report(
         tag          => 'deviceaddrnodns',
         label        => 'Addresses without DNS Entries',
         provides_csv => 1,
+        api_endpoint => 1,
     }
 );
 
@@ -28,14 +29,12 @@ get '/ajax/content/report/deviceaddrnodns' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json (\@results);
-        template 'ajax/report/deviceaddrnodns.tt', { results => $json },
-            { layout => undef };
+        template 'ajax/report/deviceaddrnodns.tt', { results => $json };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/deviceaddrnodns_csv.tt',
-            { results => \@results, },
-            { layout  => undef };
+            { results => \@results, };
     }
 };
 
